@@ -24,42 +24,29 @@ FALSE_VALUES = (
 )
 
 
-def parse_bool(v, default: Optional[bool] = None, exceptions: bool = True) -> Optional[bool]:
+def parse_bool(v: str) -> bool:
     """
     Parses boolean value
     :param v: Input string
-    :param default: Default value if exceptions=False
-    :param exceptions: Raise exception on error or not
     :return: bool
     """
-    if not exceptions:
-        logger.warning('jutil.parse.parse_bool(..., exceptions=False) is deprecated, use parse_bool_or_none')
-    if isinstance(v, bool):
-        return v
     s = str(v).lower()
     if s in TRUE_VALUES:
         return True
     if s in FALSE_VALUES:
         return False
-    if exceptions:
-        msg = _("%(value)s is not one of the available choices") % {'value': v}
-        raise ValidationError(msg)
-    return default
+    raise ValidationError(_("%(value)s is not one of the available choices") % {'value': v})
 
 
-def parse_datetime(v: str, default: Optional[datetime] = None, tz: Any = None, exceptions: bool = True) -> Optional[datetime]:
+def parse_datetime(v: str, tz: Any = None) -> datetime:
     """
     Parses ISO date/datetime string to timezone-aware datetime.
     Supports YYYY-MM-DD date strings where time part is missing.
     Returns always timezone-aware datetime (assumes UTC if timezone missing).
     :param v: Input string to parse
-    :param default: Default value to return if exceptions=False
     :param tz: Default pytz timezone or if None then use UTC as default
-    :param exceptions: Raise exception on error or not
     :return: datetime with timezone
     """
-    if not exceptions:
-        logger.warning('jutil.parse.parse_datetime(..., exceptions=False) is deprecated, use parse_datetime_or_none')
     try:
         t = django_parse_datetime(v)
         if t is None:
@@ -73,9 +60,7 @@ def parse_datetime(v: str, default: Optional[datetime] = None, tz: Any = None, e
             tz = pytz.utc
         return t if t.tzinfo else tz.localize(t)
     except Exception:
-        if exceptions:
-            raise ValidationError(_("“%(value)s” value has an invalid format. It must be in YYYY-MM-DD HH:MM[:ss[.uuuuuu]][TZ] format.") % {'value': v})
-        return default
+        raise ValidationError(_("“%(value)s” value has an invalid format. It must be in YYYY-MM-DD HH:MM[:ss[.uuuuuu]][TZ] format.") % {'value': v})
 
 
 def parse_bool_or_none(v: str) -> Optional[bool]:
@@ -84,8 +69,6 @@ def parse_bool_or_none(v: str) -> Optional[bool]:
     :param v: Input string
     :return: bool or None
     """
-    if isinstance(v, bool):
-        return v
     s = str(v).lower()
     if s in TRUE_VALUES:
         return True
